==> haskell-dbus0.10-0.10.15-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dbus0.10.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dbus
version: 0.10.15
id: dbus-0.10.15-GXZJ4QIhkMIDbUdx4b2KFp
key: dbus-0.10.15-GXZJ4QIhkMIDbUdx4b2KFp
license: GPL-3.0-only
maintainer: Andrey Sverdlichenko <blaze@ruddy.ru>
author: John Millikin <john@john-millikin.com>
stability: experimental
homepage: https://github.com/rblaze/haskell-dbus#readme
synopsis: A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.
    .
    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.
    .
    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.
    .
    Example: connect to the session bus, and get a list of active names.
    .
    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;
    .
    import Data.List (sort)
    import DBus
    import DBus.Client
    .
    main = do
    &#x20;   client <- connectSession
    &#x20;   //
    &#x20;   \-- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;   //
    &#x20;   \-- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   \-- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;   //
    &#x20;   \-- Print each name on a line, sorted so reserved names are below
    &#x20;   \-- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @
    .
    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver
category: Network, Desktop
abi: 083c345c87a70c2ad789aeda55e86214
exposed: True
exposed-modules:
    DBus DBus.Client DBus.Internal.Address DBus.Internal.Message
    DBus.Internal.Types DBus.Internal.Wire DBus.Introspection
    DBus.Socket DBus.Transport
import-dirs: /usr/lib/ghc-8.4.3/site-local/dbus-0.10.15
library-dirs: /usr/lib/ghc-8.4.3/site-local/dbus-0.10.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/dbus-0.10.15
hs-libraries: HSdbus-0.10.15-GXZJ4QIhkMIDbUdx4b2KFp
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj containers-0.5.11.0
    deepseq-1.4.3.0 libxml-sax-0.7.5-GkUm3a8rMd5IxolLzHxtC3
    network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v parsec-3.1.13.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV text-1.2.3.0 transformers-0.5.5.0
    unix-2.7.2.2 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=77866f631eefa2be10fa7c88fcec53a0
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             libxml-sax-0.7.5-GkUm3a8rMd5IxolLzHxtC3=ffb8fa77f4f82d40c9ba711087bde0c6
             network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v=9f1a3e2a2d1ba200f0b4b28f3589f138
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
haddock-interfaces: /usr/share/doc/haskell-dbus0.10/html/dbus.haddock
haddock-html: /usr/share/doc/haskell-dbus0.10/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus0.10-0.10.15-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dbus0.10.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dbus
version: 0.10.15
id: dbus-0.10.15-Jb5XAq57MVIBxcDO5BLyTB
key: dbus-0.10.15-Jb5XAq57MVIBxcDO5BLyTB
license: GPL-3.0-only
maintainer: Andrey Sverdlichenko <blaze@ruddy.ru>
author: John Millikin <john@john-millikin.com>
stability: experimental
homepage: https://github.com/rblaze/haskell-dbus#readme
synopsis: A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.
    .
    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.
    .
    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.
    .
    Example: connect to the session bus, and get a list of active names.
    .
    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;
    .
    import Data.List (sort)
    import DBus
    import DBus.Client
    .
    main = do
    &#x20;   client <- connectSession
    &#x20;   //
    &#x20;   \-- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;   //
    &#x20;   \-- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   \-- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;   //
    &#x20;   \-- Print each name on a line, sorted so reserved names are below
    &#x20;   \-- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @
    .
    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver
category: Network, Desktop
abi: 5e3c83f1a2908a02b96609d056a71f88
exposed: True
exposed-modules:
    DBus DBus.Client DBus.Internal.Address DBus.Internal.Message
    DBus.Internal.Types DBus.Internal.Wire DBus.Introspection
    DBus.Socket DBus.Transport
import-dirs: /usr/lib/ghc-8.4.3/site-local/dbus-0.10.15
library-dirs: /usr/lib/ghc-8.4.3/site-local/dbus-0.10.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/dbus-0.10.15
hs-libraries: HSdbus-0.10.15-Jb5XAq57MVIBxcDO5BLyTB
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj containers-0.5.11.0
    deepseq-1.4.3.0 libxml-sax-0.7.5-GkUm3a8rMd5IxolLzHxtC3
    network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr parsec-3.1.13.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV text-1.2.3.0 transformers-0.5.5.0
    unix-2.7.2.2 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=77866f631eefa2be10fa7c88fcec53a0
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             libxml-sax-0.7.5-GkUm3a8rMd5IxolLzHxtC3=ffb8fa77f4f82d40c9ba711087bde0c6
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
haddock-interfaces: /usr/share/doc/haskell-dbus0.10/html/dbus.haddock
haddock-html: /usr/share/doc/haskell-dbus0.10/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
